Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5919)

Unified Diff: chrome/browser/site_details.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/site_details.cc
diff --git a/chrome/browser/site_details.cc b/chrome/browser/site_details.cc
index 8ad341db3e9ade6cf764673e9a3cb7a43d58e09d..eecee2c101b9eddf5b1b2fb17e59575b5246c96e 100644
--- a/chrome/browser/site_details.cc
+++ b/chrome/browser/site_details.cc
@@ -146,12 +146,12 @@ void SiteDetails::CollectSiteInfo(WebContents* contents,
for (RenderFrameHost* frame : contents->GetAllFrames()) {
// Determine the site from the frame's origin, with a fallback to the
// frame's URL. In cases like <iframe sandbox>, we can wind up with an
// http URL but a unique origin. The origin of the resource will still
// determine process placement.
url::Origin origin = frame->GetLastCommittedOrigin();
GURL site = SiteInstance::GetSiteForURL(
context,
- origin.unique() ? frame->GetLastCommittedURL() : origin.GetURL());
+ origin.opaque() ? frame->GetLastCommittedURL() : origin.GetURL());
bool should_isolate = ShouldIsolate(context, scenario, site);

Powered by Google App Engine
@@ -146,12 +146,12 @@ void SiteDetails::CollectSiteInfo(WebContents* contents,
// Determine the site from the frame's origin, with a fallback to the
// frame's URL. In cases like <iframe sandbox>, we can wind up with an
- // http URL but a unique origin. The origin of the resource will still
+ // http URL but an opaque origin. The origin of the resource will still
// determine process placement.
url::Origin origin = frame->GetLastCommittedOrigin();
This is Rietveld 408576698